@@ -1,7 +1,7 @@
 #!/bin/bash
 
 #
-# Copyright (C) 2010-2023 Canonical
+# Copyright (C) 2010-2024 Canonical
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -23,8 +23,8 @@
 # Get fwts sources, strip out .git directory, add in necessary debian packaging
 # files, build source package ready for upload.
 #
-RELEASES="bionic focal jammy kinetic lunar mantic"
-REPO=git://kernel.ubuntu.com/hwe/fwts.git
+RELEASES="bionic focal jammy lunar mantic noble"
+REPO=https://github.com/fwts/fwts
 RELEASE_TAR_URL=http://fwts.ubuntu.com/release
 FWTS=fwts
 
