@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2023 Canonical
+ * Copyright (C) 2010-2024 Canonical
  *
  * Portions of this code original from the Linux-ready Firmware Developer Kit
  *
@@ -150,8 +150,17 @@ static int fadt_info(fwts_framework *fw)
 	flag_info(fw, "HW_REDUCED_ACPI",
 		  fadt->flags & FWTS_FACP_FLAG_HW_REDUCED_ACPI);
 	flag_info(fw, "LOW_POWER_S0_IDLE_CAPABLE",
-		  fadt->flags & FWTS_FACP_FLAG_LOW_POWER_S0_IDLE_CAPABLE);
-
+		  fadt->flags & FWTS_FACP_FLAG_LOW_POWER_S0_IDLE_CAPABLE); 
+	if ((fadt->flags & FWTS_FACP_FLAG_PERSISTENT_CPU_CACHES) == 0)
+		fwts_log_info(fw, "     PERSISTENT_CPU_CACHES is not reported");
+	else if ((fadt->flags & FWTS_FACP_FLAG_PERSISTENT_CPU_CACHES) == FWTS_FACP_FLAG_PERSISTENT_CPU_CACHES) {
+		fwts_failed(fw, LOG_LEVEL_HIGH,
+			    "FADTCPUCACHESRESERVED",
+			    "FADT persistent cpu caches value 11b should be reserved.");
+	} else {
+		fwts_log_info(fw, "     PERSISTENT_CPU_CACHES is 0x%" PRIx8,
+		(fadt->flags & FWTS_FACP_FLAG_PERSISTENT_CPU_CACHES) >> 22);
+	}
 	fwts_log_info(fw, "FADT: IA-PC Boot Architecture flag states");
 	flag_info(fw, "LEGACY_DEVICES", fadt->iapc_boot_arch &
 		  FWTS_FACP_IAPC_BOOT_ARCH_LEGACY_DEVICES);
@@ -758,53 +767,32 @@ static void acpi_table_check_fadt_smi_cmd(fwts_framework *fw)
 
 static void acpi_table_check_fadt_acpi_enable(fwts_framework *fw)
 {
-	if (fadt->acpi_enable == 0)
+	if (fadt->acpi_enable != 0) {
 		if (fadt->smi_cmd == 0)
-			fwts_passed(fw, "FADT SMI ACPI enable command is zero, "
-				    "which is allowed since SMM is not "
-				    "supported, or machine is in legacy mode.");
-		else
-			fwts_failed(fw, LOG_LEVEL_MEDIUM,
-				    "SMMHasNoAcpiEnableCmd",
-				    "FADT SMI ACPI enable command is zero, "
-				    "but this is not allowed when SMM "
-				    "is supported.");
-	else
-		if (fadt->smi_cmd == 0)
-			fwts_failed(fw, LOG_LEVEL_MEDIUM,
+			fwts_failed(fw, LOG_LEVEL_HIGH,
 				    "SMMNeedsAcpiEnableCmd",
 				    "FADT SMI ACPI enable command is non-zero, "
 				    "but SMM is not supported.");
 		else
 			fwts_passed(fw, "FADT SMI ACPI enable command is "
 				    "non-zero, and SMM is supported.");
+	}
 
 	return;
 }
 
 static void acpi_table_check_fadt_acpi_disable(fwts_framework *fw)
 {
-	if (fadt->acpi_disable == 0)
+	if (fadt->acpi_disable != 0) {
 		if (fadt->smi_cmd == 0)
-			fwts_passed(fw,
-				    "FADT SMI ACPI disable command is zero, "
-				    "which is allowed since SMM is not "
-				    "supported, or machine is in legacy mode.");
-		else
-			fwts_failed(fw, LOG_LEVEL_MEDIUM,
-				    "SMMHasNoAcpiDisableCmd",
-				    "FADT SMI ACPI disable command is zero, "
-				    "but this is not allowed when SMM "
-				    "is supported.");
-	else
-		if (fadt->smi_cmd == 0)
-			fwts_failed(fw, LOG_LEVEL_MEDIUM,
+			fwts_failed(fw, LOG_LEVEL_HIGH,
 				    "SMMNeedsAcpiDisableCmd",
 				    "FADT SMI ACPI disable command is "
 				    "non-zero, but SMM is not supported.");
 		else
 			fwts_passed(fw, "FADT SMI ACPI disable command is "
 				    "non-zero, and SMM is supported.");
+	}
 
 	return;
 }
@@ -1624,7 +1612,7 @@ static void acpi_table_check_fadt_sleep_control_reg(fwts_framework *fw)
 			fwts_failed(fw, LOG_LEVEL_MEDIUM,
 				    "SleepControlRegNotAllowed",
 				    "FADT SLEEP_CONTROL_REG is defined but "
-				    "will be ignored reduced hardware mode.");
+				    "will be ignored when not in reduced hardware mode.");
 	}
 }
 
@@ -1654,7 +1642,7 @@ static void acpi_table_check_fadt_sleep_status_reg(fwts_framework *fw)
 			fwts_failed(fw, LOG_LEVEL_MEDIUM,
 				    "SleepStatusRegNotAllowed",
 				    "FADT SLEEP_STATUS_REG is defined but "
-				    "will be ignored reduced hardware mode.");
+				    "will be ignored when not in reduced hardware mode.");
 	}
 }
 
