@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2023 Canonical
+ * Copyright (C) 2015-2024 Canonical
  * Portions added (c) 2015, Al Stone <ahs3@redhat.com>
  *
  * This program is free software; you can redistribute it and/or
@@ -118,11 +118,11 @@
 
 #define FADT_MAX_MAJOR_REVISION	((uint8_t)((FWTS_ACPI_VERSION_NOW & 0xF00) >> 8))
 #define FADT_MAX_MINOR_REVISION	((uint8_t)(FWTS_ACPI_VERSION_NOW & 0xF0) >> 4)
-#define MADT_MAX_REVISION	((uint8_t)5)
+#define MADT_MAX_REVISION	((uint8_t)6)
 
 #define SUBTABLE_UNDEFINED	0x00
 #define SUBTABLE_VARIABLE	0xff
-#define NUM_SUBTABLE_TYPES	16
+#define NUM_SUBTABLE_TYPES	24
 #define MAX_IO_APIC_ID		256 /* IO APIC ID field is 1 byte */
 
 #define SBBR_ACPI_MAJOR_VERSION 6
@@ -238,6 +238,15 @@ static struct acpi_madt_subtable_lengths spec_info[] = {
 		.lengths = { 8, 12, 10, 8, 6, 12, 16, SUBTABLE_VARIABLE,
 			     16, 16, 12, 80, 24, 24, 16, 20 }
 	},
+	{ /* for ACPI 6.5 */
+		.major_version = 6,
+		.minor_version = 5,
+		.madt_version = 6,
+		.num_types = 24,
+		.lengths = { 8, 12, 10, 8, 6, 12, 16, SUBTABLE_VARIABLE,
+			     16, 16, 12, 82, 24, 24, 16, 20, 16,
+			     15, 23, 21, 13, 19, 17, 15 }
+	},
 	{ /* terminator */
 		.major_version = 0,
 		.minor_version = 0,
@@ -562,7 +571,14 @@ static const char *madt_sub_names[] = {
 	/* 0x0e */ "GICR Redistributor",
 	/* 0x0f */ "GIC Interrupt Translation Service (ITS)",
 	/* 0x10 */ "Multiprocessor Wakeup",
-	/* 0x11 - 0x7f */ "Reserved. OSPM skips structures of the reserved type.",
+	/* 0x11 */ "CORE PIC",
+	/* 0x12 */ "LIO PIC",
+	/* 0x13 */ "HT PIC",
+	/* 0x14 */ "EIO PIC",
+	/* 0x15 */ "MSI PIC",
+	/* 0x16 */ "BIO PIC",
+	/* 0x17 */ "LPC PIC",
+	/* 0x18 - 0x7f */ "Reserved. OSPM skips structures of the reserved type.",
 	/* 0x80 - 0xff */ "Reserved for OEM use",
 	NULL
 };
@@ -1075,6 +1091,10 @@ static int madt_gicc(fwts_framework *fw,
 		mask = 0xfffffff8;
 		start = 3;
 	}
+	if (hdr->length == 82) {	/* ACPI 6.5 */
+		mask = 0xfffffff0;
+		start = 4;
+	}
 	if (gic->flags & mask)
 		fwts_failed(fw, LOG_LEVEL_MEDIUM,
 			    "MADTGICFLags",
@@ -1087,6 +1107,15 @@ static int madt_gicc(fwts_framework *fw,
 			    "properly set to zero.",
 			    madt_sub_names[hdr->type], start);
 
+	if (hdr->length == 82) {	/* ACPI 6.5 */
+		/* If the Enabled bit is set, Online Capable bit is reserved and must be zero. */
+		if ((gic->flags & 1) && (gic->flags & (1 << 3)))
+			fwts_failed(fw, LOG_LEVEL_MEDIUM,
+				    "MADTGICBadFLag",
+				    "MADT %s, flags, if Enable bit is set, the Online Capable bit "
+				    "is reserved and must be zero.",madt_sub_names[hdr->type]);
+	}
+
 	if (gic->parking_protocol_version != 0 &&
 	    gic->parking_protocol_version != 1)
 		fwts_failed(fw, LOG_LEVEL_MEDIUM,
@@ -1434,6 +1463,60 @@ static int madt_mp_wakup(fwts_framework *fw,
 	return (hdr->length - sizeof(fwts_acpi_madt_sub_table_header));
 }
 
+static int madt_core_pic(fwts_framework *fw,
+			     fwts_acpi_madt_sub_table_header *hdr,
+			     uint8_t *data)
+{
+
+	fwts_acpi_madt_core_pic *core_pic = (fwts_acpi_madt_core_pic *)data;
+
+	if (core_pic->version > 1)
+		fwts_failed(fw, LOG_LEVEL_LOW,
+			    "SPECMADTPicVersion",
+			    "MADT %s version should not over 1, "
+			    "but instead have 0x%" PRIx32 ".",
+			    madt_sub_names[hdr->type], core_pic->version);
+	else
+		fwts_passed(fw,
+			    "MADT %s version is properly set.",
+			    madt_sub_names[hdr->type]);
+
+	if (core_pic->flag & 0xfffffffe)
+		fwts_failed(fw, LOG_LEVEL_MEDIUM,
+			    "SPECMADTPicFlag",
+			    "MADT %s flags, bits 1..31 are reserved "
+			    "and should be zero, but are set as: %" PRIx32 ".",
+			    madt_sub_names[hdr->type], core_pic->flag);
+	else
+		fwts_passed(fw,
+			    "MADT %s flags, bits 1..31 are reserved "
+			    "and set to zero.",
+			    madt_sub_names[hdr->type]);
+
+	return (hdr->length - sizeof(fwts_acpi_madt_sub_table_header));
+}
+
+static int madt_general_pic(fwts_framework *fw,
+			     fwts_acpi_madt_sub_table_header *hdr,
+			     uint8_t *data)
+{
+
+	uint8_t *version = (uint8_t *)data;
+
+	if (*version > 1)
+		fwts_failed(fw, LOG_LEVEL_LOW,
+			    "SPECMADTPicVersion",
+			    "MADT %s version should not over 1, "
+			    "but instead have 0x%" PRIx32 ".",
+			    madt_sub_names[hdr->type], *version);
+	else
+		fwts_passed(fw,
+			    "MADT %s version is properly set.",
+			    madt_sub_names[hdr->type]);
+
+	return (hdr->length - sizeof(fwts_acpi_madt_sub_table_header));
+}
+
 static void madt_ioapic_sapic_compare(fwts_framework *fw,
 				     int num_ioapics,
 				     int num_iosapics)
@@ -1660,6 +1743,19 @@ static int madt_subtables(fwts_framework *fw)
 			skip = madt_mp_wakup(fw, hdr, data);
 			break;
 
+		case FWTS_MADT_CORE_PIC:
+			skip = madt_core_pic(fw, hdr, data);
+			break;
+
+		case FWTS_MADT_LIO_PIC:
+		case FWTS_MADT_HT_PIC:
+		case FWTS_MADT_EIO_PIC:
+		case FWTS_MADT_MSI_PIC:
+		case FWTS_MADT_BIO_PIC:
+		case FWTS_MADT_LPC_PIC:
+			skip = madt_general_pic(fw, hdr, data);
+			break;
+
 		case FWTS_MADT_RESERVED:
 			fwts_failed(fw, LOG_LEVEL_MEDIUM,
 				    "SPECMADTSubReservedID",
