@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2023 Canonical
+ * Copyright (C) 2010-2024 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,7 +33,10 @@
 #define PM_SUSPEND_PMUTILS		"pm-suspend"
 #define PM_SUSPEND_HYBRID_PMUTILS	"pm-suspend-hybrid"
 #define PM_SUSPEND_PATH			"/sys/power/mem_sleep"
-#define PM_S2IDLE_SLP_S0		"/sys/kernel/debug/pmc_core/slp_s0_residency_usec"
+#define PM_SUSPEND_LAST_HW_SLEEP	"/sys/power/suspend_stats/last_hw_sleep"
+#define PM_SUSPEND_TOTAL_HW_SLEEP	"/sys/power/suspend_stats/total_hw_sleep"
+#define WAKEUP_SOURCE_PATH		"/sys/kernel/debug/wakeup_sources"
+#define INTEL_PM_S2IDLE_SLP_S0		"/sys/kernel/debug/pmc_core/slp_s0_residency_usec"
 
 static char sleep_type[7];
 static char sleep_type_orig[7];
@@ -52,6 +55,135 @@ static float s3_resume_time = 15.0;	/* Maximum allowed resume time */
 static bool s3_hybrid = false;
 static char *s3_hook = NULL;		/* Hook to run after each S3 */
 static char *s3_sleep_type = NULL;	/* The sleep type(s3 or s2idle) */
+static bool s3_wakeup_src = false;	/* dump wakeup source for debug */
+
+typedef struct {
+	char		name[32];
+	unsigned long	active_count;
+	unsigned long	event_count;
+	unsigned long	wakeup_count;
+	unsigned long	expire_count;
+	long int	active_since;
+	long int	total_time;
+	long int	max_time;
+	long int	last_change;
+	long int	prevent_suspend_time;
+} wakeup_source;
+
+static int read_wakeup_source(fwts_list *source)
+{
+	FILE		*fp;
+	char		name[32];
+	unsigned long	active_count;
+	unsigned long	event_count;
+	unsigned long	wakeup_count;
+	unsigned long	expire_count;
+	long int	active_since;
+	long int	total_time;
+	long int	max_time;
+	long int	last_change;
+	long int	prevent_suspend_time;
+	int		c;
+
+	fwts_list_init(source);
+
+	if ((fp = fopen(WAKEUP_SOURCE_PATH, "r")) == NULL)
+		return FWTS_ERROR;
+
+	/* skip first line */
+	while (c = fgetc(fp), c != '\n' && c != EOF);
+
+	while (fscanf(fp, "%s\t%lu\t\t%lu\t\t%lu\t\t%lu\t\t%ld\t\t%ld\t\t%ld\t\t%ld\t\t%ld\n",
+			name, &active_count, &event_count,
+			&wakeup_count, &expire_count, &active_since,
+			&total_time, &max_time, &last_change,
+			&prevent_suspend_time) == 10) {
+		wakeup_source *wakeup_source_data;
+
+		wakeup_source_data  = calloc(1, sizeof(wakeup_source));
+		if (wakeup_source_data == NULL) {
+			fwts_list_free_items(source, free);
+			(void)fclose(fp);
+			return FWTS_ERROR;
+		}
+
+		memcpy(wakeup_source_data->name , name, sizeof(name));
+		wakeup_source_data->active_count = active_count;
+		wakeup_source_data->event_count = event_count;
+		wakeup_source_data->wakeup_count = wakeup_count;
+		wakeup_source_data->expire_count = expire_count;
+		wakeup_source_data->active_since = active_since;
+		wakeup_source_data->total_time = total_time;
+		wakeup_source_data->max_time = max_time;
+		wakeup_source_data->last_change = last_change;
+		wakeup_source_data->prevent_suspend_time = prevent_suspend_time;
+	
+		fwts_list_append(source, wakeup_source_data);
+
+	}
+
+	(void)fclose(fp);
+
+	return FWTS_OK;
+}
+
+static void dump_wakeup_source(fwts_framework *fw, fwts_list *source)
+{
+	if (fwts_list_len(source) > 0) {
+		fwts_list_link *item;
+
+
+		fwts_list_foreach(item, source) {
+			wakeup_source *wakeup_source_data =
+				fwts_list_data(wakeup_source *, item);
+
+			fwts_log_info_verbatim(fw, "%s\t%lu\t%lu\t%lu\t%lu\t%ld\t%ld\t%ld\t%ld\t%ld\n",
+			wakeup_source_data->name, wakeup_source_data->active_count, wakeup_source_data->event_count,
+			wakeup_source_data->wakeup_count, wakeup_source_data->expire_count, wakeup_source_data->active_since,
+			wakeup_source_data->total_time, wakeup_source_data->max_time, wakeup_source_data->last_change,
+			wakeup_source_data->prevent_suspend_time);
+		}
+	} else
+		fwts_log_info(fw, "No wakeup source found.");
+}
+
+static void wakeup_source_cmp(fwts_framework *fw, fwts_list *suspend_source, fwts_list *resume_source)
+{
+
+	fwts_list_link *item1;
+	fwts_list_link *item2;
+
+	if (fwts_list_len(suspend_source) != fwts_list_len(resume_source)) {
+		fwts_log_info_verbatim(fw, "wakeup source list length differ, cannot get wakeup sources.\n");
+		return;
+	}
+
+	item1 = fwts_list_head(suspend_source);
+	item2 = fwts_list_head(resume_source);
+
+	while ((item1 != NULL) && (item2 != NULL)) {
+		wakeup_source *data1 = fwts_list_data(wakeup_source *, item1);
+		wakeup_source *data2 = fwts_list_data(wakeup_source *, item2);
+		if (data1->event_count < data2->event_count) {
+			fwts_log_info_verbatim(fw, "wakeup source name: \"%s\" wakeup event was signaled.\n", data1->name);
+			if (s3_wakeup_src) {
+				fwts_log_info_verbatim(fw, "%s %lu %lu %lu %lu %ld %ld %ld %ld %ld\n",
+				data1->name, data1->active_count, data1->event_count,
+				data1->wakeup_count, data1->expire_count, data1->active_since,
+				data1->total_time, data1->max_time, data1->last_change,
+				data1->prevent_suspend_time);
+
+				fwts_log_info_verbatim(fw, "%s %lu %lu %lu %lu %ld %ld %ld %ld %ld\n",
+				data2->name, data2->active_count, data2->event_count,
+				data2->wakeup_count, data2->expire_count, data2->active_since,
+				data2->total_time, data2->max_time, data2->last_change,
+				data2->prevent_suspend_time);
+			}
+		}
+		item1 = fwts_list_next(item1);
+		item2 = fwts_list_next(item2);
+	}
+}
 
 static int s3_init(fwts_framework *fw)
 {
@@ -231,16 +363,12 @@ static int wrap_pmutils_do_suspend(fwts_pm_method_vars *fwts_settings,
 	return status;
 }
 
-/*
- *  get_s2_idle_residency()
- *	read PM_S2IDLE_SLP_S0, return 0 if it is not available
- */
-static uint64_t get_s2_idle_residency(void)
+static uint64_t get_uint64_sysfs(const char *path)
 {
-	char *str;
 	uint64_t val;
+	char *str;
 
-	str = fwts_get(PM_S2IDLE_SLP_S0);
+	str = fwts_get(path);
 	if (!str)
 		return 0;
 
@@ -250,12 +378,55 @@ static uint64_t get_s2_idle_residency(void)
 	return val;
 }
 
+/*
+ *  get_last_s2idle_residency()
+ *
+ *  Returns:
+ *  - Hardware sleep residency from the last sleep cycle
+ *  - 0 if it is not available
+ *
+ */
+static uint64_t get_last_s2idle_residency(void)
+{
+	if (access(PM_SUSPEND_LAST_HW_SLEEP, F_OK) != 0)
+		return 0;
+
+	return get_uint64_sysfs(PM_SUSPEND_LAST_HW_SLEEP);
+}
+
+/*
+ *  get_total_s2idle_residency()
+ *  @fname: Optional parameter to set the filename used to check residency
+ *
+ *  Returns:
+ *  - Total hardware sleep residency since the system was booted
+ *  - 0 if it is not available
+ *
+ */
+static uint64_t get_total_s2idle_residency(const char **fname)
+{
+	const char *check;
+	uint64_t val;
+
+	if (access(PM_SUSPEND_TOTAL_HW_SLEEP, F_OK) == 0)
+		check = PM_SUSPEND_TOTAL_HW_SLEEP;
+	else
+		check = INTEL_PM_S2IDLE_SLP_S0;
+
+	val = get_uint64_sysfs(check);
+
+	if (fname)
+		*fname = check;
+
+	return val;
+}
+
 static int s3_do_suspend_resume(fwts_framework *fw,
 	int *hw_errors,
 	int *pm_errors,
 	int *hook_errors,
 	int *s2idle_errors,
-	uint64_t *s2idle_residency,
+	uint64_t *total_s2idle_residency,
 	int delay,
 	int percent)
 {
@@ -267,6 +438,9 @@ static int s3_do_suspend_resume(fwts_framework *fw,
 	char *command = NULL;
 	char *quirks = NULL;
 	fwts_pm_method_vars *fwts_settings;
+	fwts_list suspend_wakeup_soure;
+	fwts_list resume_wakeup_soure;
+	bool wk_src_found = false;
 
 	int (*do_suspend)(fwts_pm_method_vars *, const int, int*, const char*);
 
@@ -344,9 +518,24 @@ static int s3_do_suspend_resume(fwts_framework *fw,
 
 	fwts_wakealarm_trigger(fw, delay);
 
+	if (read_wakeup_source(&suspend_wakeup_soure) != FWTS_ERROR) {
+		wk_src_found = true;
+	}
+
 	/* Do S3 / S2idle here */
 	status = do_suspend(fwts_settings, percent, &duration, command);
 
+	if (wk_src_found) {
+		if (read_wakeup_source(&resume_wakeup_soure) != FWTS_ERROR) {
+			(void)wakeup_source_cmp(fw, &suspend_wakeup_soure, &resume_wakeup_soure);
+			if (s3_wakeup_src) {
+				(void)dump_wakeup_source(fw, &suspend_wakeup_soure);
+				fwts_log_info(fw, "versus after:");
+				(void)dump_wakeup_source(fw, &resume_wakeup_soure);
+			}
+		}
+	}
+
 	fwts_log_info(fw, "pm-action returned %d after %d seconds.", status, duration);
 
 	if (s3_device_check) {
@@ -380,15 +569,28 @@ static int s3_do_suspend_resume(fwts_framework *fw,
 	}
 
 	if (!strncmp(sleep_type, "s2idle", strlen("s2idle"))) {
-		uint64_t residency = get_s2_idle_residency();
-		bool intel;
-		if (fwts_cpu_is_Intel(&intel) == FWTS_OK && intel && residency <= *s2idle_residency) {
+		const char *fname;
+		uint64_t residency = get_total_s2idle_residency(&fname);
+
+		if (residency <= *total_s2idle_residency) {
 			(*s2idle_errors)++;
-			fwts_failed(fw, LOG_LEVEL_HIGH, "S2idleNotDeepest",
-				"Expected %s to increase from %" PRIu64 ", got %" PRIu64 ".",
-				PM_S2IDLE_SLP_S0, *s2idle_residency, residency);
+			fwts_failed(fw, LOG_LEVEL_CRITICAL, "S2idleNotDeepest",
+				    "Expected %s to increase from %" PRIu64 ", got %" PRIu64 ".",
+				    fname, *total_s2idle_residency, residency);
+		}
+		*total_s2idle_residency = residency;
+
+		residency = get_last_s2idle_residency();
+		if (duration > 10 && residency) {
+			float pct = (float)residency / ((float)duration * 1000000) * 100.0;
+			if (pct < 70) {
+				(*s2idle_errors)++;
+				fwts_failed(fw, LOG_LEVEL_HIGH, "S2idleNotDeepest",
+					    "Expected %s to be at least 70%% of the last sleep cycle, got %.2f%%.",
+					    PM_SUSPEND_LAST_HW_SLEEP, pct);
+				} else
+					fwts_log_info(fw, "Spent %.2f%% of %ds in hardware sleep state", pct, duration);
 		}
-		*s2idle_residency = residency;
 	}
 
 	if (duration < delay) {
@@ -433,6 +635,9 @@ static int s3_do_suspend_resume(fwts_framework *fw,
 			"enter the requested power saving state.");
 	}
 
+	fwts_list_free_items(&suspend_wakeup_soure, free);
+	fwts_list_free_items(&resume_wakeup_soure, free);
+
 tidy:
 	free(command);
 	free(quirks);
@@ -589,7 +794,7 @@ static int s3_test_multiple(fwts_framework *fw)
 	int resume_too_long = 0;
 	int awake_delay = s3_min_delay * 1000;
 	int delta = (int)(s3_delay_delta * 1000.0);
-	uint64_t s2idle_residency = get_s2_idle_residency();
+	uint64_t total_s2idle_residency = get_total_s2idle_residency(NULL);
 	int pm_debug;
 
 #if FWTS_ENABLE_LOGIND
@@ -615,7 +820,7 @@ static int s3_test_multiple(fwts_framework *fw)
 			fwts_log_error(fw, "Cannot read kernel log.");
 
 		ret = s3_do_suspend_resume(fw, &hw_errors, &pm_errors, &hook_errors,
-					   &s2idle_errors, &s2idle_residency,
+					   &s2idle_errors, &total_s2idle_residency,
 					   s3_sleep_delay, percent);
 		if (ret == FWTS_OUT_OF_MEMORY) {
 			fwts_log_error(fw, "%s cycle %d failed - out of memory error.", sleep_type, i+1);
@@ -836,6 +1041,9 @@ static int s3_options_handler(fwts_framework *fw, int argc, char * const argv[],
 		case 12:
 			s3_sleep_type = optarg;
 			break;
+		case 13:
+			s3_wakeup_src = true;
+			break;
 		}
 	}
 	return FWTS_OK;
@@ -854,7 +1062,8 @@ static fwts_option s3_options[] = {
 	{ "s3-resume-time", 	"", 1, "Maximum expected resume time in seconds, e.g. --s3-resume-time=5.1" },
 	{ "s3-hybrid",		"", 0, "Run S3 with hybrid sleep, i.e. saving system states as S4 does." },
 	{ "s3-resume-hook hook","", 1, "Run a hook script after each S3 resume, 0 exit indicates success." },
-	{ "s3-sleep-type"	,"", 1, "Set the sleep type for testing S3 or s2idle." },
+	{ "s3-sleep-type",	"", 1, "Set the sleep type for testing S3 or s2idle." },
+	{ "s3-dump-wakeup-src",	"", 0, "dump the all device wakeup sources suspend/resume.(For debug)"}, 
 	{ NULL, NULL, 0, NULL }
 };
 
