@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2023 Canonical
+ * Copyright (C) 2010-2024 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -93,6 +93,7 @@ static fwts_wmi_known_guid fwts_wmi_known_guids[] = {
 	{ "F1DDEE52-063C-4784-A11E-8A06684B9BF4", "dell-wmi-sysman", "Dell" },
 	{ "70FE8229-D03B-4214-A1C6-1F884B1A892A", "dell-wmi-sysman", "Dell" },
 	{ "8A42EA14-4F2A-FD45-6422-0087F7A7E608", "dell-wmi-ddv", "Dell" },
+	{ "F1DDEE52-063C-4784-A11E-8A06684B9B01", "dell-smm-hwmon", "Dell" },
 	{ "ABBC0F72-8EA1-11D1-00A0-C90629100000", "eeepc-wmi",	"Asus" },
 	{ "97845ED0-4E6D-11DE-8A39-0800200C9A66", "eeepc-wmi",	"Asus" },
 	{ "DEADBEEF-2001-0000-00A0-C90629100000", "gigabyte-wmi",	"Gigabyte" },
@@ -124,6 +125,7 @@ static fwts_wmi_known_guid fwts_wmi_known_guids[] = {
 	{ "F7CC25EC-D20B-404C-8903-0ED4359C18AE", "surface3-wmi", "Surface3" },
 	{ "C364AC71-36DB-495A-8494-B439D472A505", "tc110-wmi",	"HP Compaq" },
 	{ "59142400-C6A3-40FA-BADB-8A2652834100", "toshiba_acpi", "Toshiba" },
+	{ "05901221-D566-11D1-B2F0-00A0C9062910", "wmi-bmof", "Generic" },
 	{ NULL, NULL, NULL }
 };
 
@@ -459,6 +461,12 @@ static void wmi_parse_wdg_data(
 			wmi_known_driver(fw, known);
 			wmi_block_query_exist_count(fw, info, acpi_object_name, guid_str);
 		}
+
+		if (info->instance == 0)
+			fwts_failed(fw, LOG_LEVEL_LOW, "WMIZeroInstance",
+				    "GUID %s has zero instances", guid_str);
+		else
+			fwts_passed(fw, "%s has more than zero instances", guid_str);
 	}
 
 	if (events && all_events_known)
