@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2023, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -254,6 +254,7 @@ static void
 LsGenerateListing (
     UINT32                  FileId)
 {
+    UINT32                  WalkMode = ASL_WALK_VISIT_DOWNWARD | ASL_WALK_VISIT_DB_SEPARATELY;
 
     /* Start at the beginning of both the source and AML files */
 
@@ -271,7 +272,7 @@ LsGenerateListing (
 
         LsDoOffsetTableHeader (FileId);
 
-        TrWalkParseTree (AslGbl_ParseTreeRoot, ASL_WALK_VISIT_DOWNWARD,
+        TrWalkParseTree (AslGbl_CurrentDB, WalkMode,
             LsAmlOffsetWalk, NULL, (void *) ACPI_TO_POINTER (FileId));
         LsDoOffsetTableFooter (FileId);
         return;
@@ -279,7 +280,7 @@ LsGenerateListing (
 
     /* Process all parse nodes */
 
-    TrWalkParseTree (AslGbl_ParseTreeRoot, ASL_WALK_VISIT_DOWNWARD,
+    TrWalkParseTree (AslGbl_CurrentDB, WalkMode,
         LsAmlListingWalk, NULL, (void *) ACPI_TO_POINTER (FileId));
 
     /* Final processing */
@@ -847,7 +848,7 @@ LsFinishSourceListing (
         FlPrintFile (FileId, "\n\nSummary of errors and warnings\n\n");
         AePrintErrorLog (FileId);
         FlPrintFile (FileId, "\n");
-        UtDisplaySummary (FileId);
+        UtDisplayOneSummary (FileId, TRUE);
         FlPrintFile (FileId, "\n");
     }
 }
