@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2019, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2023, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -277,6 +277,11 @@ AcpiRsDumpResourceList (
                 ResourceList->Type);
             return;
         }
+        else if (!ResourceList->Type)
+        {
+            ACPI_ERROR ((AE_INFO, "Invalid Zero Resource Type"));
+            return;
+        }
 
         /* Sanity check the length. It must not be zero, or we loop forever */
 
@@ -460,6 +465,11 @@ AcpiRsDumpDescriptor (
             AcpiRsOutString (Name, Table->Pointer [*Target & 0x07]);
             break;
 
+        case ACPI_RSD_6BITFLAG:
+
+            AcpiRsOutInteger8 (Name, (ACPI_GET8 (Target) & 0x3F));
+            break;
+
         case ACPI_RSD_SHORTLIST:
             /*
              * Short byte list (single line output) for DMA and IRQ resources
