@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2023 Canonical
+ * Copyright (C) 2010-2024 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,7 +35,7 @@
 #include <limits.h>
 #include <fcntl.h>
 
-#define DMI_VERSION			(0x0360)
+#define DMI_VERSION			(0x0370)
 #define VERSION_MAJOR(v)		((v) >> 8)
 #define VERSION_MINOR(v)		((v) & 0xff)
 
@@ -299,7 +299,8 @@ static const fwts_dmi_type_length type_info[] = {
 	{ 17, 0x208, 0x207, 0x22 },
 	{ 17, 0x302, 0x208, 0x28 },
 	{ 17, 0x303, 0x302, 0x54 },
-	{ 17, MAX_VERSION, 0x303, 0x5c },
+	{ 17, 0x307, 0x303, 0x5c },
+	{ 17, MAX_VERSION, 0x307, 0x64 },
 	{ 19, 0x207, 0x201, 0xf },
 	{ 19, MAX_VERSION, 0x207, 0x1f },
 	{ 20, 0x207, 0x201, 0x13 },
@@ -1410,7 +1411,7 @@ static void dmicheck_entry(fwts_framework *fw,
 					table, addr, "Status", 0x18);
 			dmi_reserved_bits_check(fw, table, addr, "Status", hdr, sizeof(uint8_t), 0x18, 3, 5);
 			dmi_reserved_bits_check(fw, table, addr, "Status", hdr, sizeof(uint8_t), 0x18, 7, 7);
-			dmi_min_max_uint8_check(fw, table, addr, "Processor Upgrade", hdr, 0x19, 0x1, 0x48);
+			dmi_min_max_uint8_check(fw, table, addr, "Processor Upgrade", hdr, 0x19, 0x1, 0x50);
 			if (hdr->length < 0x23)
 				break;
 			dmi_str_check(fw, table, addr, "Serial Number", hdr, 0x20);
@@ -1499,8 +1500,6 @@ static void dmicheck_entry(fwts_framework *fw,
 			if (hdr->length < 0x0d)
 				break;
 
-			dmi_reserved_bits_check(fw, table, addr, "Slot Characteristics 2", hdr, sizeof(uint8_t), 0x0c, 7, 7);
-
 			if (hdr->length < 0x11)
 				break;
 			if (!((data[0x5] == 0x06) ||
@@ -1638,7 +1637,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			fwts_dmi_value_range t16_ranges[] = {{0x1, 0xa}, {0xa0, 0xa4}};
 			dmi_ranges_uint8_check(fw, table, addr, "Location", hdr, 0x4, t16_ranges);
 			dmi_min_max_uint8_check(fw, table, addr, "Use", hdr, 0x5, 0x1, 0x7);
-			dmi_min_max_uint8_check(fw, table, addr, "Error Corrrection Type", hdr, 0x6, 0x1, 0x7);
+			dmi_min_max_uint8_check(fw, table, addr, "Error Correction Type", hdr, 0x6, 0x1, 0x7);
 			dmi_min_max_uint32_check(fw, table, addr, "Maximum Capacity", hdr, 0x7, 0, 0x80000000);
 			if (hdr->length < 0x17)
 				break;
