@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2023 Canonical
+ * Copyright (C) 2010-2024 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -56,7 +56,8 @@
 #define FWTS_FACP_FLAG_FORCE_APIC_PHYSICAL_DESTINATION_MODE	(0x00080000)
 #define FWTS_FACP_FLAG_HW_REDUCED_ACPI				(0x00100000)
 #define FWTS_FACP_FLAG_LOW_POWER_S0_IDLE_CAPABLE		(0x00200000)
-#define FWTS_FACP_FLAG_RESERVED_MASK				(0xffc00000)
+#define FWTS_FACP_FLAG_PERSISTENT_CPU_CACHES			(0x00c00000)
+#define FWTS_FACP_FLAG_RESERVED_MASK				(0xff000000)
 
 #define FWTS_FACP_IAPC_BOOT_ARCH_LEGACY_DEVICES		(0x0001)
 #define FWTS_FACP_IAPC_BOOT_ARCH_8042			(0x0002)
@@ -85,10 +86,12 @@
 #define FWTS_GAS_ADDR_SPACE_ID_GPIO		(0x08)
 #define FWTS_GAS_ADDR_SPACE_ID_GSB		(0x09)
 #define FWTS_GAS_ADDR_SPACE_ID_PCC		(0x0a)
+#define FWTS_GAS_ADDR_SPACE_ID_PRM		(0x0b)
 #define FWTS_GAS_ADDR_SPACE_ID_FFH		(0x7f)
 
-#define FWTS_ACPI_VERSION_NOW	(FWTS_ACPI_VERSION_64)
-#define FWTS_ACPI_VERSION_NEXT	(0x650)
+#define FWTS_ACPI_VERSION_NOW	(FWTS_ACPI_VERSION_65)
+#define FWTS_ACPI_VERSION_NEXT	(0x660)
+#define FWTS_ACPI_VERSION_65	(0x650)
 #define FWTS_ACPI_VERSION_64 	(0x640)
 #define FWTS_ACPI_VERSION_63 	(0x630)
 #define FWTS_ACPI_VERSION_62 	(0x620)
@@ -444,6 +447,17 @@ typedef struct {
 	uint32_t	reserved2;
 } __attribute__ ((packed)) fwts_acpi_table_initiator_affinity;
 
+typedef struct {
+	uint8_t		type;
+	uint8_t		length;
+	uint8_t		reserved1;
+	uint8_t		device_handle_type;
+	uint32_t	proximity_domain;
+	uint8_t		device_handle[16];
+	uint32_t	flags;
+	uint32_t	reserved2;
+} __attribute__ ((packed)) fwts_acpi_table_port_affinity;
+
 /*
  * ACPI HPET (HPET IA-PC High Precision Event Timer Table),
  *    3.2.4 The ACPI 2.0 HPET Description Table (HPET)
@@ -523,6 +537,13 @@ typedef enum {
 	FWTS_MADT_GIC_R_REDISTRIBUTOR,
 	FWTS_MADT_GIC_ITS,
 	FWTS_MADT_MP_WAKEUP,
+	FWTS_MADT_CORE_PIC,
+	FWTS_MADT_LIO_PIC,
+	FWTS_MADT_HT_PIC,
+	FWTS_MADT_EIO_PIC,
+	FWTS_MADT_MSI_PIC,
+	FWTS_MADT_BIO_PIC,
+	FWTS_MADT_LPC_PIC,
 	FWTS_MADT_RESERVED, /* does not have defined structure */
 	FWTS_MADT_OEM /* does not have defined structure */
 } fwts_acpi_madt_type;
@@ -683,6 +704,15 @@ typedef struct {
 	uint64_t	mail_box_address;
 } __attribute__ ((packed)) fwts_acpi_madt_mp_wakeup;
 
+/* New in ACPI 6.5 Core Programmable Interrupt Controller (CORE PIC) Structure, 5.2.12.20 */
+/* Type 17, FWTS_MADT_CORE_PIC */
+typedef struct {
+	uint8_t		version;
+	uint32_t	acpi_processor_id;
+	uint32_t	physical_processor_id;
+	uint32_t	flag;
+} __attribute__ ((packed)) fwts_acpi_madt_core_pic;
+
 /*
  * ACPI TCPA (Trusted Computing Platform Alliance Capabilities Table)
  *   http://www.kuro5hin.org/story/2002/10/27/16622/530,
@@ -1079,7 +1109,24 @@ typedef struct {
 } __attribute__ ((packed)) fwts_acpi_table_rasf;
 
 /*
- * ACPI MPST (Memory Power State Table), 5.2.21
+ * ACPI RAS2 (RAS2 Feature Table), 5.2.21
+ */
+typedef struct {
+	uint8_t		pcc_id;
+	uint16_t	reserved;
+	uint8_t         feature_type;
+	uint32_t	instance;
+} __attribute__ ((packed)) fwts_acpi_ras2_pcc_desc;
+
+typedef struct {
+	fwts_acpi_table_header		header;
+	uint16_t			reserved;
+	uint16_t			num_pcc_descriptors;
+	fwts_acpi_ras2_pcc_desc		pcc_descriptors[0];
+} __attribute__ ((packed)) fwts_acpi_table_ras2;
+
+/*
+ * ACPI MPST (Memory Power State Table), 5.2.22
  */
 typedef struct {
 	fwts_acpi_table_header	header;
@@ -1661,7 +1708,7 @@ typedef struct {
 	uint8_t		stop_bits;
 	uint8_t		flow_control;
 	uint8_t		terminal_type;
-	uint8_t		reserved2;
+	uint8_t		language;
 	uint16_t	pci_device_id;
 	uint16_t	pci_vendor_id;
 	uint8_t		pci_bus_number;
@@ -1669,7 +1716,11 @@ typedef struct {
 	uint8_t		pci_function_number;
 	uint32_t	pci_flags;
 	uint8_t		pci_segment;
-	uint32_t	reserved3;
+	uint32_t	uart_clock_freq;
+	uint32_t	precise_baud_rate;
+	uint16_t	namespace_str_length;
+	uint16_t	namespace_str_offset;
+	char		namespace_str[0];
 } __attribute__ ((packed)) fwts_acpi_table_spcr;
 
 /*
@@ -2141,6 +2192,19 @@ typedef struct {
 	*/
 } __attribute__ ((packed)) fwts_acpi_table_iort_pmcg_node;
 
+typedef struct {
+	uint64_t	physical_range_offset;
+	uint64_t	physical_range_length;
+	uint32_t	reserved;
+} __attribute__ ((packed)) fwts_acpi_table_iort_mem_rng_des;
+
+typedef struct {
+	fwts_acpi_table_iort_node iort_node;
+	uint32_t	flags;
+	uint32_t	num_mem_rng_des;
+	uint32_t	mem_rng_des_offset;
+} __attribute__ ((packed)) fwts_acpi_table_iort_rmr_node;
+
 /*
  * ACPI STAO (Status Override Table)
  *   http://wiki.xenproject.org/mediawiki/images/0/02/Status-override-table.pdf
@@ -2590,4 +2654,199 @@ typedef struct {
     fwts_acpi_table_header	header;
 } __attribute__ ((packed)) fwts_acpi_table_mpam;
 
+/*
+ * iSCSI Boot Firmware Table (iBFT)
+ * https://download.microsoft.com/download/1/e/5/1e5a2287-366c-431a-8e05-b958540230b1/iBFT.docx
+ */
+typedef enum {
+    FWTS_IBFT_RESERVED   = 0,
+    FWTS_IBFT_CONTROL    = 1,
+    FWTS_IBFT_INITIATOR  = 2,
+    FWTS_IBFT_NIC        = 3,
+    FWTS_IBFT_TARGET     = 4,
+    FWTS_IBFT_EXTENSIONS = 5,
+    FWTS_IBFT_UNKNOWN    = 0xFF
+} fwts_ibft_structure_types;
+
+typedef struct {
+	char		signature[4];
+	uint32_t	length;
+	uint8_t		revision;
+	uint8_t		checksum;
+	char		oem_id[6];
+	char		oem_tbl_id[8];
+	uint8_t		reserved[24];
+} __attribute__ ((packed)) fwts_acpi_ibft_header;
+
+typedef struct {
+	uint8_t		structure_id;
+	uint8_t		version;
+	uint16_t	length;
+	uint8_t		index;
+	uint8_t		flags;
+} __attribute__ ((packed)) fwts_acpi_ibft_standard;
+
+typedef struct {
+        fwts_acpi_ibft_standard std;
+        uint16_t                extensions;
+	uint16_t		initiator_offset;
+	uint16_t		nic_0_offset;
+	uint16_t		target_0_offset;
+	uint16_t		nic_1_offset;
+	uint16_t		target_1_offset;
+} __attribute__ ((packed)) fwts_acpi_ibft_control;
+
+typedef struct {
+        fwts_acpi_ibft_standard std;
+	uint8_t			isns_server[16];
+	uint8_t			slp_server[16];
+	uint8_t			primary_radius_server[16];
+	uint8_t			secondary_radius_server[16];
+	uint16_t		initiator_name_length;
+	uint16_t		initiator_name_offset;
+} __attribute__ ((packed)) fwts_acpi_ibft_initiator;
+
+typedef struct {
+        fwts_acpi_ibft_standard std;
+	uint8_t			ip_address[16];
+	uint8_t			subnet_mask_prefix;
+	uint8_t			origin;
+	uint8_t			gateway[16];
+	uint8_t			primary_dns[16];
+	uint8_t			secondary_dns[16];
+	uint8_t			dhcp[16];
+	uint16_t		vlan;
+	uint8_t			mac_address[6];
+	uint16_t		pci_bus_dev_func;
+	uint16_t		host_name_length;
+	uint16_t		host_name_offset;
+} __attribute__ ((packed)) fwts_acpi_ibft_nic;
+
+typedef struct {
+        fwts_acpi_ibft_standard std;
+	uint8_t			target_ip_address[16];
+	uint16_t		target_ip_socket;
+	uint64_t		target_boot_lun;
+	uint8_t			chap_type;
+	uint8_t			nic_sssociation;
+	uint16_t		target_name_length;
+	uint16_t		target_name_offset;
+	uint16_t		chap_name_length;
+	uint16_t		chap_name_offset;
+	uint16_t		chap_secret_length;
+	uint16_t		chap_secret_offset;
+	uint16_t		reverse_chap_name_length;
+	uint16_t		reverse_chap_name_offset;
+	uint16_t		reverse_chap_secret_length;
+	uint16_t		reverse_chap_secret_offset;
+} __attribute__ ((packed)) fwts_acpi_ibft_target;
+
+typedef struct {
+	fwts_acpi_ibft_header	header;
+	uint32_t		ivinfo;
+	uint64_t		reserved;
+} __attribute__ ((packed)) fwts_acpi_table_ibft;
+
+/*
+ * Virtual I/O Translation (VIOT) Table
+ * ACPI6.5 5.2.32
+ */
+typedef struct
+{
+
+	uint8_t		type;
+	uint8_t		reserved;
+	uint16_t	length;
+} __attribute__ ((packed)) fwts_acpi_viot_node_hdr;
+
+typedef struct
+{
+	fwts_acpi_viot_node_hdr hdr;
+	uint32_t	endpoint_start;
+	uint16_t	pci_seg_start;
+	uint16_t	pci_seg_end;
+	uint16_t	pci_bdf_start;
+	uint16_t	pci_bdf_end;
+	uint16_t	output_node;
+	uint8_t		reserved[6];
+} __attribute__ ((packed)) fwts_acpi_viot_pci_rng_node;
+
+typedef struct
+{
+	fwts_acpi_viot_node_hdr hdr;
+	uint32_t	endpoint_id;
+	uint64_t	base_addr;
+	uint16_t	output_node;
+	uint8_t		reserved[6];
+} __attribute__ ((packed)) fwts_acpi_viot_mmio_ep_node;
+
+typedef struct
+{
+	fwts_acpi_viot_node_hdr hdr;
+	uint16_t	pci_seg;
+	uint16_t	pci_bdf_num;
+	uint64_t	reserved;
+} __attribute__ ((packed)) fwts_acpi_viot_pci_iommu_node;
+
+typedef struct
+{
+	fwts_acpi_viot_node_hdr hdr;
+	uint32_t	reserved;
+	uint64_t	base_addr;
+} __attribute__ ((packed)) fwts_acpi_viot_mmio_iommu_node;
+
+typedef struct {
+	fwts_acpi_table_header	header;
+	uint16_t		node_count;
+	uint16_t		node_offset;
+	uint64_t		reserved;
+} __attribute__ ((packed)) fwts_acpi_table_viot;
+
+/*
+ * Miscellaneous GUIDed Table Entries
+ * ACPI6.5 5.2.33
+ */
+typedef struct {
+	uint8_t		entry_guid[16];
+	uint32_t	entry_len;
+	uint32_t	revision;
+	uint32_t	producer_id;
+	uint8_t		data[0];
+} __attribute__ ((packed)) fwts_acpi_misc_guided_entry;
+
+typedef struct {
+	fwts_acpi_table_header		header;
+	fwts_acpi_misc_guided_entry 	entry[0];
+} __attribute__ ((packed)) fwts_acpi_table_misc;
+
+/*
+ * CC Event Log ACPI Table
+ * ACPI6.5 5.2.34
+ */
+typedef struct {
+	fwts_acpi_table_header	header;
+	uint8_t			cc_type;
+	uint8_t			cc_subtype;
+	uint16_t		reserved;
+	uint64_t		laml;
+	uint64_t		lasa;
+} __attribute__ ((packed)) fwts_acpi_table_ccel;
+
+/*
+ * Storage Volume Key Location Table
+ * ACPI6.5 5.2.35
+ */
+typedef struct {
+	uint16_t	key_type;
+	uint16_t	key_format;
+	uint32_t	key_size;
+	uint64_t	key_address;
+} __attribute__ ((packed)) fwts_acpi_skvl_key_struct;
+
+typedef struct {
+	fwts_acpi_table_header		header;
+	uint32_t			key_count;
+	fwts_acpi_skvl_key_struct 	key_struct[0];
+} __attribute__ ((packed)) fwts_acpi_table_skvl;
+
 #endif
