@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2022 Canonical
+ * Copyright (C) 2020-2024 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -116,7 +116,9 @@ typedef enum {
 	EV_EFI_HCRTM_EVENT			= 0x80000010,
 	EV_EFI_VARIABLE_AUTHORITY		= 0x800000e0,
 	EV_EFI_SPDM_FIRMWARE_BLOB		= 0x800000e1,
-	EV_EFI_SPDM_FIRMWARE_CONFIG		= 0x800000e2
+	EV_EFI_SPDM_FIRMWARE_CONFIG		= 0x800000e2,
+	EV_EFI_SPDM_DEVICE_POLICY		= 0x800000e3,
+	EV_EFI_SPDM_DEVICE_AUTHORITY		= 0x800000e4,
 } fwts_tpmlog_event_type;
 
 
@@ -172,6 +174,15 @@ typedef struct {
 */
 } __attribute__ ((packed)) fwts_tcg_pcr_event2;
 
+typedef uint64_t uefi_physical_address;
+typedef struct {
+    uefi_physical_address	image_location_in_memory;
+    uint64_t			image_len_in_memory;
+    uint64_t			image_link_time_address;
+    uint64_t			length_of_device_path;
+    uint8_t			device_path[0];
+} __attribute__ ((packed)) uefi_image_load_event;
+
 void fwts_tpm_data_hexdump(fwts_framework *fw, const uint8_t *data,
 	const size_t size, const char *str);
 uint8_t fwts_tpm_get_hash_size(const TPM2_ALG_ID hash);
