@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2023 Canonical
+ * Copyright (C) 2010-2024 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -277,7 +277,7 @@ static const acpi_eval_error errors[] = {
 	{ AE_AML_TARGET_TYPE,		LOG_LEVEL_HIGH,		"AEAMLTargetType",	"Target type",
 		"A target operand of an incorrect type was encountered."
 	},
-	{ AE_AML_PROTOCOL,		LOG_LEVEL_HIGH,		"AEAMLViolateProtocol",	"Violattion protcol",
+	{ AE_AML_PROTOCOL,		LOG_LEVEL_HIGH,		"AEAMLViolateProtocol",	"Violation protocol",
 		"Violation of a fixed ACPI protocol."
 	},
 	{ AE_AML_BUFFER_LENGTH, 	LOG_LEVEL_HIGH,		"AEAMLBadBufLength",	"Bad buffer length",
@@ -789,7 +789,7 @@ int fwts_method_package_elements_all_type(
 			fwts_failed(fw, LOG_LEVEL_CRITICAL, tmp,
 				"%s package element %" PRIu32 " was not the expected "
 				"type '%s', was instead type '%s'.",
-				name, i,
+				name ? name : "unknown", i,
 				fwts_method_type_name(type),
 				fwts_method_type_name(obj->Package.Elements[i].Type));
 			failed = true;
@@ -827,7 +827,7 @@ int fwts_method_package_elements_type__(
 			fwts_failed(fw, LOG_LEVEL_CRITICAL, tmp,
 				"%s package element %" PRIu32 " (%s) was not the expected "
 				"type '%s', was instead type '%s'.",
-				name, i, info[i].name,
+				name ? name : "unknown", i, info[i].name,
 				fwts_method_type_name(info[i].type),
 				fwts_method_type_name(obj->Package.Elements[i].Type));
 			failed = true;
