@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2023 Canonical
+ * Copyright (C) 2010-2024 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1485,8 +1485,8 @@ void fwts_acpi_reserved_zero_array(
 	char label[20];
 	uint8_t i;
 
-	strncpy(label + 4, "ReservedNonZero", sizeof(label) - 4);
-	strncpy(label, table, 4);	/* ACPI table name is 4 char long */
+	strncpy(label, table, sizeof(label) - 1);
+	strcat(label, "ReservedNonZero");
 
 	for (i = 0; i < length; i++)
 		value += data[i];
@@ -1629,7 +1629,8 @@ static const char *get_space_id_name(const uint8_t id)
 		"IPMI (0x7)",
 		"General PurposeIO (0x8)",
 		"GenericSerialBus (0x9)",
-		"Platform Communications Channel (0xa)"
+		"Platform Communications Channel (0xa)",
+		"Platform Runtime Mechanism (0xb)"
 	};
 
 	if (id < FWTS_ARRAY_SIZE(gas_space_id_names))
