@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2023 Canonical
+ * Copyright (C) 2010-2024 Canonical
  * Some of this work - Copyright (C) 2016-2021 IBM
  *
  * This program is free software; you can redistribute it and/or
@@ -146,10 +146,10 @@ static fwts_option fwts_framework_options[] = {
 static fwts_list fwts_framework_test_list = FWTS_LIST_INIT;
 
 static const char *fwts_copyright[] = {
-	"Some of this work - Copyright (c) 1999 - 2021, Intel Corp. All rights reserved.",
-	"Some of this work - Copyright (c) 2010 - 2021, Canonical.",
-	"Some of this work - Copyright (c) 2016 - 2021, IBM.",
-	"Some of this work - Copyright (c) 2017 - 2021, ARM Ltd.",
+	"Some of this work - Copyright (c) 1999 - 2023, Intel Corp. All rights reserved.",
+	"Some of this work - Copyright (c) 2010 - 2023, Canonical.",
+	"Some of this work - Copyright (c) 2016 - 2023, IBM.",
+	"Some of this work - Copyright (c) 2017 - 2023, ARM Ltd.",
 	NULL
 };
 
@@ -1567,7 +1567,8 @@ int fwts_framework_args(const int argc, char **argv)
 		fprintf(stderr, "%s: Cannot open results log '%s'"
 			" (you may need to remove it to set proper"
 			" permissions).\n",
-			argv[0], fw->results_logname);
+			argv[0],
+			fwts_log_get_filenames(fw->results_logname, fw->log_type));
 		goto tidy_close;
 	}
 
