@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2023 Canonical
+ * Copyright (C) 2014-2024 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -936,6 +936,6 @@ static fwts_framework_ops uefibootpath_ops = {
 	.minor_tests     = uefibootpath_tests
 };
 
-FWTS_REGISTER("uefibootpath", &uefibootpath_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_UEFI | FWTS_FLAG_BATCH | FWTS_FLAG_ROOT_PRIV);
+FWTS_REGISTER("uefibootpath", &uefibootpath_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_UEFI | FWTS_FLAG_BATCH | FWTS_FLAG_ROOT_PRIV | FWTS_FLAG_XBBR);
 
 #endif
