@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2023 Canonical
+ * Copyright (C) 2012-2024 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -2018,7 +2018,7 @@ static void getvariable_test_invalid(
 	}
 	fwts_failed(fw, LOG_LEVEL_HIGH,
 		"UEFIRuntimeGetVariableInvalid",
-		"GetVariable wuth %s failed to get an error return status, "
+		"GetVariable with %s failed to get an error return status, "
 		"expected EFI_INVALID_PARAMETER.", test);
 
 	return;
